@@ -200,6 +200,16 @@ namespace heif {
 
     std::vector<std::shared_ptr<Box>> get_child_boxes(uint32_t short_type) const;
 
+    template <typename T>
+    std::vector<std::shared_ptr<T>> get_typed_child_boxes(uint32_t short_type) const {
+      auto boxes = get_child_boxes(short_type);
+      std::vector<std::shared_ptr<T>> typedBoxes;
+      for (const auto& box : boxes) {
+        typedBoxes.push_back(std::dynamic_pointer_cast<T>(box));
+      }
+      return typedBoxes;
+    }
+
     const std::vector<std::shared_ptr<Box>>& get_all_child_boxes() const
     { return m_children; }
 
@@ -472,9 +482,15 @@ namespace heif {
     const std::string& get_content_type() const
     { return m_content_type; }
 
+    const std::string& get_content_encoding() const
+    { return m_content_encoding; }
+
     void set_content_type(const std::string& content_type)
     { m_content_type = content_type; }
 
+    void set_content_encoding(const std::string& content_encoding)
+    { m_content_encoding = content_encoding; }
+
     void derive_box_version() override;
 
     Error write(StreamWriter& writer) const override;
@@ -641,6 +657,8 @@ namespace heif {
 
     Error write(StreamWriter& writer) const override;
 
+    void insert_entries_from_other_ipma_box(const Box_ipma& b);
+
   protected:
     Error parse(BitstreamRange& range) override;
 
@@ -694,14 +712,25 @@ namespace heif {
     Box_irot(const BoxHeader& hdr) : Box(hdr)
     {}
 
+    Box_irot()
+    {
+      set_short_type(fourcc("irot"));
+      set_is_full_box(false);
+    }
+
     std::string dump(Indent&) const override;
 
     int get_rotation() const
     { return m_rotation; }
 
+    // Only multiples of 90 are allowed (0,90,180,270).
+    void set_rotation_ccw(int rot) { m_rotation = rot; }
+
   protected:
     Error parse(BitstreamRange& range) override;
 
+    Error write(StreamWriter& writer) const override;
+
   private:
     int m_rotation = 0; // in degrees (CCW)
   };
@@ -713,6 +742,12 @@ namespace heif {
     Box_imir(const BoxHeader& hdr) : Box(hdr)
     {}
 
+    Box_imir()
+    {
+      set_short_type(fourcc("imir"));
+      set_is_full_box(false);
+    }
+
     enum class MirrorDirection : uint8_t
     {
       Vertical = 0,
@@ -722,11 +757,15 @@ namespace heif {
     MirrorDirection get_mirror_direction() const
     { return m_axis; }
 
+    void set_mirror_direction(MirrorDirection dir) { m_axis=dir; }
+
     std::string dump(Indent&) const override;
 
   protected:
     Error parse(BitstreamRange& range) override;
 
+    Error write(StreamWriter& writer) const override;
+
   private:
     MirrorDirection m_axis = MirrorDirection::Vertical;
   };
