@@ -36,6 +36,8 @@
 #include <windows.h>
 #endif
 
+#include "metadata_compression.h"
+
 using namespace heif;
 
 // TODO: make this a decoder option
@@ -283,11 +285,15 @@ Error HeifFile::parse_heif_file(BitstreamRange& range)
                  heif_suberror_No_ipco_box);
   }
 
-  m_ipma_box = std::dynamic_pointer_cast<Box_ipma>(m_iprp_box->get_child_box(fourcc("ipma")));
-  if (!m_ipma_box) {
+  auto ipma_boxes = m_iprp_box->get_typed_child_boxes<Box_ipma>(fourcc("ipma"));
+  if (ipma_boxes.empty()) {
     return Error(heif_error_Invalid_input,
                  heif_suberror_No_ipma_box);
   }
+  for (size_t i=1;i<ipma_boxes.size();i++) {
+    ipma_boxes[0]->insert_entries_from_other_ipma_box(*ipma_boxes[i]);
+  }
+  m_ipma_box = ipma_boxes[0];
 
   m_iloc_box = std::dynamic_pointer_cast<Box_iloc>(m_meta_box->get_child_box(fourcc("iloc")));
   if (!m_iloc_box) {
@@ -618,7 +624,27 @@ Error HeifFile::get_compressed_image_data(heif_item_id ID, std::vector<uint8_t>*
            item_type == "iovl" ||
            item_type == "Exif" ||
            (item_type == "mime" && content_type == "application/rdf+xml")) {
-    error = m_iloc_box->read_data(*item, m_input_stream, m_idat_box, data);
+
+    bool read_uncompressed = true;
+    if (item_type == "mime") {
+      std::string encoding = infe_box->get_content_encoding();
+      if (encoding == "deflate") {
+#if WITH_DEFLATE_HEADER_COMPRESSION
+        read_uncompressed = false;
+        std::vector<uint8_t> compressed_data;
+        error = m_iloc_box->read_data(*item, m_input_stream, m_idat_box, &compressed_data);
+        *data = inflate(compressed_data);
+#else
+        return Error(heif_error_Unsupported_feature,
+                     heif_suberror_Unsupported_header_compression_method,
+                     encoding);
+#endif
+      }
+    }
+
+    if (read_uncompressed) {
+      error = m_iloc_box->read_data(*item, m_input_stream, m_idat_box, data);
+    }
   }
 
   if (error != Error::Ok) {
@@ -698,6 +724,65 @@ void HeifFile::add_clap_property(heif_item_id id, uint32_t clap_width, uint32_t
 }
 
 
+void HeifFile::add_orientation_properties(heif_item_id id, heif_orientation orientation)
+{
+  int rotation_ccw = 0;
+  Box_imir::MirrorDirection mirror;
+  bool has_mirror = false;
+
+  switch (orientation) {
+    case heif_orientation_normal:
+      break;
+    case heif_orientation_flip_horizontally:
+      mirror = Box_imir::MirrorDirection::Horizontal;
+      has_mirror = true;
+      break;
+    case heif_orientation_rotate_180:
+      rotation_ccw = 180;
+      break;
+    case heif_orientation_flip_vertically:
+      mirror = Box_imir::MirrorDirection::Vertical;
+      has_mirror = true;
+      break;
+    case heif_orientation_rotate_90_cw_then_flip_horizontally:
+      rotation_ccw = 270;
+      mirror = Box_imir::MirrorDirection::Horizontal;
+      has_mirror = true;
+      break;
+    case heif_orientation_rotate_90_cw:
+      rotation_ccw = 270;
+      break;
+    case heif_orientation_rotate_90_cw_then_flip_vertically:
+      rotation_ccw = 270;
+      mirror = Box_imir::MirrorDirection::Vertical;
+      has_mirror = true;
+      break;
+    case heif_orientation_rotate_270_cw:
+      rotation_ccw = 90;
+      break;
+  }
+
+  // omit rotation when angle is 0
+  if (rotation_ccw!=0) {
+    auto irot = std::make_shared<Box_irot>();
+    irot->set_rotation_ccw(rotation_ccw);
+
+    int index = m_ipco_box->append_child_box(irot);
+
+    m_ipma_box->add_property_for_item_ID(id, Box_ipma::PropertyAssociation{false, uint16_t(index + 1)});
+  }
+
+  if (has_mirror) {
+    auto imir = std::make_shared<Box_imir>();
+    imir->set_mirror_direction(mirror);
+
+    int index = m_ipco_box->append_child_box(imir);
+
+    m_ipma_box->add_property_for_item_ID(id, Box_ipma::PropertyAssociation{false, uint16_t(index + 1)});
+  }
+}
+
+
 void HeifFile::add_pixi_property(heif_item_id id, uint8_t c1, uint8_t c2, uint8_t c3)
 {
   auto pixi = std::make_shared<Box_pixi>();
