@@ -71,6 +71,23 @@ if [ "$WITH_X265" = "1" ]; then
         "
 fi
 
+if [ "$WITH_DAV1D" = "1" ]; then
+    INSTALL_PACKAGES="$INSTALL_PACKAGES \
+        nasm \
+        ninja-build \
+        python3-pip \
+        python3-setuptools \
+        python3-wheel \
+        "
+fi
+
+if [ "$WITH_RAV1E" = "1" ]; then
+    INSTALL_PACKAGES="$INSTALL_PACKAGES \
+        cargo \
+        nasm \
+        "
+fi
+
 if [ ! -z "$CHECK_LICENSES" ]; then
     sudo curl --location --output /usr/bin/licensecheck "https://github.com/Debian/devscripts/raw/v2.16.5/scripts/licensecheck.pl"
     sudo chmod a+x /usr/bin/licensecheck
@@ -93,6 +110,11 @@ fi
 
 if [ "$MINGW" == "32" ]; then
     sudo dpkg --add-architecture i386
+    # https://github.com/actions/runner-images/issues/4589
+    sudo rm -f /etc/apt/sources.list.d/microsoft-prod.list
+    sudo apt-get update
+    sudo apt-get install -y --allow-downgrades libgd3/focal libpcre2-8-0/focal libpcre2-16-0/focal libpcre2-32-0/focal libpcre2-posix2/focal
+    sudo apt-get purge -y libmono* moby* mono* php* libgdiplus libpcre2-posix3 libzip4
     INSTALL_PACKAGES="$INSTALL_PACKAGES \
         binutils-mingw-w64-i686 \
         g++-mingw-w64-i686 \
@@ -101,7 +123,6 @@ if [ "$MINGW" == "32" ]; then
         wine-stable \
         wine32 \
         "
-    UPDATE_APT=1
 elif [ "$MINGW" == "64" ]; then
     INSTALL_PACKAGES="$INSTALL_PACKAGES \
         binutils-mingw-w64-x86-64 \
@@ -162,3 +183,21 @@ elif [ "$MINGW" == "64" ]; then
         sudo update-alternatives --set x86_64-w64-mingw32-g++ /usr/bin/x86_64-w64-mingw32-g++-posix
     fi
 fi
+
+if [ "$WITH_DAV1D" = "1" ]; then
+    pip3 install --user meson
+
+    export PATH="$PATH:$HOME/.local/bin"
+    cd third-party
+    sh dav1d.cmd # dav1d does not support this option anymore: -Denable_avx512=false
+    cd ..
+fi
+
+if [ "$WITH_RAV1E" = "1" ]; then
+    cargo install --force cargo-c
+
+    export PATH="$PATH:$HOME/.cargo/bin"
+    cd third-party
+    sh rav1e.cmd
+    cd ..
+fi
